<?php

namespace Drupal\entity_gallery\Controller;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\Controller\EntityViewController;

/**
 * Defines a controller to render a single entity gallery in preview.
 */
class EntityGalleryPreviewController extends EntityViewController {

  /**
   * {@inheritdoc}
   */
  public function view(EntityInterface $entity_gallery_preview, $view_mode_id = 'full', $langcode = NULL) {
    $entity_gallery_preview->preview_view_mode = $view_mode_id;
    $build = parent::view($entity_gallery_preview, $view_mode_id);

    $build['#attached']['library'][] = 'entity_gallery/drupal.entity_gallery.preview';

    // Don't render cache previews.
    unset($build['#cache']);

    foreach ($entity_gallery_preview->uriRelationships() as $rel) {
      // Set the entity gallery path as the canonical URL to prevent duplicate
      // content.
      $build['#attached']['html_head_link'][] = array(
        array(
        'rel' => $rel,
        'href' => $entity_gallery_preview->url($rel),
        )
        , TRUE);

      if ($rel == 'canonical') {
        // Set the non-aliased canonical path as a default shortlink.
        $build['#attached']['html_head_link'][] = array(
          array(
            'rel' => 'shortlink',
            'href' => $entity_gallery_preview->url($rel, array('alias' => TRUE)),
          )
        , TRUE);
      }
    }

    return $build;
  }

  /**
   * The _title_callback for the page that renders a single entity gallery in
   * preview.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity_gallery_preview
   *   The current entity gallery.
   *
   * @return string
   *   The page title.
   */
  public function title(EntityInterface $entity_gallery_preview) {
    return $this->entityManager->getTranslationFromContext($entity_gallery_preview)->label();
  }

}
